<?php
// $Id: gnupg.admin.inc,v 1.1 2008/10/16 05:25:38 arto Exp $

//////////////////////////////////////////////////////////////////////////////
// Settings form

function gnupg_admin_settings() {
  $form = array();

  $form['gnupg'] = array('#type' => 'fieldset', '#title' => t('GnuPG settings'), '#collapsible' => TRUE, '#collapsed' => FALSE);
  $form['gnupg']['gnupg_exec'] = array(
    '#type'          => 'textfield',
    '#title'         => t('Path to GnuPG executable'),
    '#default_value' => GNUPG_EXEC,
    '#size'          => 60,
    '#maxlength'     => 255,
    '#required'      => TRUE,
    '#description'   => t('A file system path to the <code>gpg</code> binary. On Unix systems, this would typically be located at <code>/usr/bin/gpg</code> or <code>/usr/local/bin/gpg</code>. On Mac OS X with MacPorts, the path would typically be <code>/opt/local/bin/gpg</code>.'),
  );
  $form['gnupg']['gnupg_homedir'] = array(
    '#type'          => 'textfield',
    '#title'         => t('Path to GnuPG home directory'),
    '#default_value' => GNUPG_HOMEDIR,
    '#size'          => 60,
    '#maxlength'     => 255,
    '#required'      => TRUE,
    '#description'   => t('A file system path to the directory where <code>gpg</code> stores its configuration and keyrings. On Unix systems, this would typically be located at %path. If the directory doesn\'t exist, an attempt will be made to create it. Note that as this directory contains GnuPG\'s secure keyring, it is <strong>critical</strong> that you ensure the directory\'s access permissions are correctly set (i.e. not world-readable) and that the directory is not web accessible. Remember that security will only be as strong as the weakest link in the chain. For more information, please refer to <code>INSTALL.txt</code>.', array('%path' => '~/.gnupg')),
  );
  $form['gnupg']['gnupg_keyid'] = array(
    '#type'          => 'select',
    '#title'         => t('GnuPG default key ID'),
    '#default_value' => GNUPG_KEYID,
    '#options'       => array_merge(array('' => t('(none)')), gnupg_get_keys()),
    '#description'   => t('The system public key, that is, the public key that will be used to e.g. send secure e-mail to the system administrator. This would typically be the system administrator\'s personal public key, or else a public key specifically created for this server or site. You can safely leave this empty for the time being.'),
  );

  return system_settings_form($form);
}

function gnupg_admin_settings_validate($form, &$form_state) {
  extract($form_state['values'], EXTR_SKIP | EXTR_REFS);

  if (!file_exists($gnupg_exec)) {
    form_set_error('gnupg_exec', t('The GnuPG binary %path does not exist.', array('%path' => $gnupg_exec)));
  }
  else if (!is_executable($gnupg_exec)) {
    form_set_error('gnupg_exec', t('The GnuPG binary %path is not executable.', array('%path' => $gnupg_exec)));
  }

  gnupg_secure_homedir($gnupg_homedir = rtrim($gnupg_homedir, '/\\'), 'gnupg_homedir');
}
